==> mem0ai-0.1.56-py3-none-any.whl: mem0/llms/groq.py <==
import json
import os
from typing import Dict, List, Optional

try:
    from groq import Groq
except ImportError:
    raise ImportError("The 'groq' library is required. Please install it using 'pip install groq'.")

from mem0.configs.llms.base import BaseLlmConfig
from mem0.llms.base import LLMBase


class GroqLLM(LLMBase):
    def __init__(self, config: Optional[BaseLlmConfig] = None):
        super().__init__(config)

        if not self.config.model:
            self.config.model = "llama3-70b-8192"

        api_key = self.config.api_key or os.getenv("GROQ_API_KEY")
        self.client = Groq(api_key=api_key)

    def generate_response(
        self,
        messages: List[Dict[str, str]],
        response_format=None
    ):
        """
        Generate a response based on the given messages using Groq.

        Args:
            messages (list): List of message dicts containing 'role' and 'content'.
            response_format (str or object, optional): Format of the response. Defaults to "text".

        Returns:
            str: The generated response.
        """
        params = {
            "model": self.config.model,
            "messages": messages,
            "temperature": self.config.temperature,
            "max_tokens": self.config.max_tokens,
            "top_p": self.config.top_p,
        }
        if response_format:
            params["response_format"] = response_format

        response = self.client.chat.completions.create(**params)
        return response.choices[0].message.content

==> mem0ai-0.1.57-py3-none-any.whl: mem0/llms/groq.py <==
import json
import os
from typing import Dict, List, Optional

try:
    from groq import Groq
except ImportError:
    raise ImportError("The 'groq' library is required. Please install it using 'pip install groq'.")

from mem0.configs.llms.base import BaseLlmConfig
from mem0.llms.base import LLMBase


class GroqLLM(LLMBase):
    def __init__(self, config: Optional[BaseLlmConfig] = None):
        super().__init__(config)

        if not self.config.model:
            self.config.model = "llama3-70b-8192"

        api_key = self.config.api_key or os.getenv("GROQ_API_KEY")
        self.client = Groq(api_key=api_key)

    def generate_response(self, messages: List[Dict[str, str]], response_format=None):
        """
        Generate a response based on the given messages using Groq.

        Args:
            messages (list): List of message dicts containing 'role' and 'content'.
            response_format (str or object, optional): Format of the response. Defaults to "text".

        Returns:
            str: The generated response.
        """
        params = {
            "model": self.config.model,
            "messages": messages,
            "temperature": self.config.temperature,
            "max_tokens": self.config.max_tokens,
            "top_p": self.config.top_p,
        }
        if response_format:
            params["response_format"] = response_format

        response = self.client.chat.completions.create(**params)
        return response.choices[0].message.content
